@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import datetime
 import functools
 import io
 import json
@@ -19,6 +19,7 @@ import logging
 import os.path
 import pathlib
 import sys
+import time
 
 import cloudevents.exceptions as cloud_exceptions
 import flask
@@ -414,9 +415,12 @@ class LazyWSGIApp:
 
 
 print("start")
+print(datetime.now())
 app = LazyWSGIApp()
 
 
+
+
 class DummyErrorHandler:
     def __init__(self):
         pass
